{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
osCommerce Product Manager for Windows (oscpmwin).
Copyright 2003,2004,2005 by Mario A. Valdez-Ramirez.

You can contact Mario A. Valdez-Ramirez
by email at mario@mariovaldez.org or paper mail at
Olmos 809, San Nicolas, NL. 66495, Mexico.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
unit openpicdlg;

interface

USES
  Dialogs, StdCtrls, ExtCtrls, Classes, Graphics;

TYPE

opmT_OpenPictureDialog = CLASS (TOpenDialog)
  PRIVATE
    opm_Panel_OPD_Preview : TPanel;
    opm_Label_OPD_PictureData1 : TLabel;
    opm_Bevel_OPD_Preview : TBevel;
    opm_Image_OPD_Preview : TImage;
    opm_CheckBox_OPD_AllowPreview : TCheckBox;
    opm_OPD_Filename : STRING;
    opm_OPD_AllowPreview : BOOLEAN;
  PROTECTED
    PROCEDURE DoSelectionChange; OVERRIDE;
    PROCEDURE DoShow; OVERRIDE;
    PROPERTY ImageCtrl: TImage READ opm_Image_OPD_Preview;
    PROPERTY PictureData1: TLabel READ opm_Label_OPD_PictureData1;
  PUBLISHED
    PROPERTY Filter;
  PUBLIC
    CONSTRUCTOR Create(AOwner: TComponent); OVERRIDE;
    FUNCTION Execute: Boolean; OVERRIDE;
  END;

implementation

uses Math, Forms, Controls, SysUtils, Windows;

{$R OPENPICDLG.RES}


{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
CONSTRUCTOR opmT_OpenPictureDialog.Create (AOwner: TComponent);
BEGIN
  INHERITED Create (AOwner);
  Filter := GraphicFilter (TGraphic);
  opm_OPD_AllowPreview := TRUE;
  opm_Panel_OPD_Preview := TPanel.Create (SELF);
  opm_Panel_OPD_Preview.Name := 'opm_Panel_OPD_Preview';
  opm_Panel_OPD_Preview.Caption := '';
  opm_Panel_OPD_Preview.BorderStyle := bsNone;
  opm_Panel_OPD_Preview.BevelInner := bvNone;
  opm_Panel_OPD_Preview.BevelOuter := bvNone;
  opm_Panel_OPD_Preview.SetBounds (204, 5, 169, 180);
  opm_Panel_OPD_Preview.Align := alClient;

  opm_Label_OPD_PictureData1 := TLabel.Create (SELF);
  opm_Label_OPD_PictureData1.Name := 'opm_Label_OPD_PictureData1';
  opm_Label_OPD_PictureData1.Caption := '';
  opm_Label_OPD_PictureData1.SetBounds (1, 1, 160, 60);
  opm_Label_OPD_PictureData1.Align := alTop;
  opm_Label_OPD_PictureData1.AutoSize := FALSE;
  opm_Label_OPD_PictureData1.WordWrap := TRUE;
  opm_Label_OPD_PictureData1.Parent := opm_Panel_OPD_Preview;

  opm_Bevel_OPD_Preview := TBevel.Create (SELF);
  opm_Bevel_OPD_Preview.SetBounds (1, 1, 157, 56);
  opm_Bevel_OPD_Preview.Shape := bsBottomLine;
  opm_Bevel_OPD_Preview.Style := bsLowered;
  opm_Bevel_OPD_Preview.Parent := opm_Panel_OPD_Preview;

  opm_CheckBox_OPD_AllowPreview := TCheckBox.Create (SELF);
  opm_CheckBox_OPD_AllowPreview.Caption := 'Allow Preview';
  opm_CheckBox_OPD_AllowPreview.Checked := TRUE;
  opm_CheckBox_OPD_AllowPreview.SetBounds (5, 61, 150, 20);
  opm_CheckBox_OPD_AllowPreview.Align := alTop;
  opm_CheckBox_OPD_AllowPreview.Parent := opm_Panel_OPD_Preview;

  opm_Image_OPD_Preview := TImage.Create (SELF);
  opm_Image_OPD_Preview.Name := 'opm_Image_OPD_Preview';
  opm_Image_OPD_Preview.Align := alClient;
  opm_Image_OPD_Preview.Proportional := TRUE;
  opm_Image_OPD_Preview.Stretch := TRUE;
  opm_Image_OPD_Preview.Center := TRUE;
  opm_Image_OPD_Preview.IncrementalDisplay := TRUE;
  opm_Image_OPD_Preview.ShowHint := FALSE;
  opm_Image_OPD_Preview.Parent := opm_Panel_OPD_Preview;
END;


{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
PROCEDURE opmT_OpenPictureDialog.DoSelectionChange;
VAR
  FileRecord : TSearchRec;
BEGIN
  Application.HideHint;
  IF (Filename <> opm_OPD_Filename) THEN
    BEGIN
      opm_OPD_Filename := Filename;
      IF (FileExists (opm_OPD_Filename) AND (GetFileAttributes (PCHAR (opm_OPD_Filename)) <> $FFFFFFFF)) THEN
        BEGIN
          IF (opm_CheckBox_OPD_AllowPreview.Checked = TRUE) THEN
            TRY
              opm_Image_OPD_Preview.Picture.LoadFromFile (opm_OPD_Filename);
              IF (SysUtils.FINDFIRST (opm_OPD_Filename, faAnyFile, FileRecord) = 0) THEN
                BEGIN
                  opm_Label_OPD_PictureData1.Caption := INTTOSTR (opm_Image_OPD_Preview.Picture.Width) + ' x ' + INTTOSTR (opm_Image_OPD_Preview.Picture.Height) +
                                                        ' (' + FLOATTOSTR (ROUNDTO ((FileRecord.Size / 1024), -1)) + ' kb)' +
                                                        #13#10 + FileRecord.Name;
                  SysUtils.FINDCLOSE (FileRecord);
                END
              ELSE opm_Label_OPD_PictureData1.Caption := INTTOSTR (opm_Image_OPD_Preview.Picture.Width) + ' x ' + INTTOSTR (opm_Image_OPD_Preview.Picture.Height);
            EXCEPT
              opm_Image_OPD_Preview.Picture := NIL;
              opm_Label_OPD_PictureData1.Caption := '';
            END
          ELSE
            BEGIN
              opm_Image_OPD_Preview.Picture := NIL;
              opm_Label_OPD_PictureData1.Caption := '';
            END;
        END;
    END;
  INHERITED DoSelectionChange;
end;



{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
PROCEDURE opmT_OpenPictureDialog.DoShow;
VAR
  PreviewRect, StaticRect: TRect;
BEGIN
  GetClientRect (Handle, PreviewRect);
  StaticRect := GetStaticRect;
  PreviewRect.Left := StaticRect.Left + (StaticRect.Right - StaticRect.Left);
  INC (PreviewRect.Top, 5);
  INC (PreviewRect.Left, 5);
  DEC (PreviewRect.Bottom, 20);
  DEC (PreviewRect.Right, 10);
  opm_Panel_OPD_Preview.BoundsRect := PreviewRect;
  opm_Panel_OPD_Preview.ParentWindow := Handle;
  opm_Image_OPD_Preview.Picture := NIL;
  opm_Label_OPD_PictureData1.Caption := '';
  opm_OPD_Filename := '';
  inherited DoShow;
END;


{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
{%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%}
FUNCTION opmT_OpenPictureDialog.Execute;
BEGIN
  Template := 'OPMOPENPICDLG';
  Execute := INHERITED Execute;
END;


end.
